@@ -1,7 +1,7 @@
 /*Wallch - WallpaperChanger
 A tool for changing Desktop Wallpapers automatically
 with lots of features
-Copyright © 2011 by Alex Solanos and Leon Vytanos
+Copyright © 2011 by Alex Solanos and Leon Vitanos
 
 This program is free software; you can redistribute it and/or
 modify it under the terms of the GNU General Public License
@@ -20,7 +20,7 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.*
 #ifndef QOPENCVWIDGET_H
 #define QOPENCVWIDGET_H
 
-#include <opencv/cv.h>
+#include <opencv/highgui.h>
 #include <QPixmap>
 #include <QLabel>
 #include <QWidget>
